@@ -25,6 +25,13 @@ struct keymap {
 struct Window windowStack[20];
 struct Window * currentWindow = NULL;
 
+char * helplineStack[20];
+char ** currentHelpline = NULL;
+
+static char * defaultHelpLine = 
+"  <Tab>/<Alt-Tab> between elements   |  <Space> selects   |  <F12> next screen"
+;
+
 struct newtColors newtDefaultColorPalette = {
 	"white", "blue", 			/* root fg, bg */     
 	"black", "lightgray",			/* border fg, bg */
@@ -41,6 +48,8 @@ struct newtColors newtDefaultColorPalette = {
 	"yellow", "blue",			/* active listbox fg, bg */
 	"black", "lightgray",			/* textbox fg, bg */
 	"lightgray", "black",			/* active textbox fg, bg */
+	"white", "blue",			/* help line */
+	"yellow", "blue",			/* root text */
 };
 
 static struct keymap keymap[] = {
@@ -98,7 +107,7 @@ void newtRefresh(void) {
 }
 
 void newtCls(void) {
-    SLsmg_set_color(COLORSET_ROOT);
+    SLsmg_set_color(NEWT_COLORSET_ROOT);
     SLsmg_gotorc(0, 0);
     SLsmg_erase_eos();
 
@@ -107,6 +116,7 @@ void newtCls(void) {
 
 int newtInit(void) {
     struct winsize ws;
+    char * MonoValue, * MonoEnv = "NEWT_MONO";
 
     /* use the version variable just to be sure it gets included */
     strlen(version);
@@ -118,7 +128,12 @@ int newtInit(void) {
 	SLtt_Screen_Cols = ws.ws_col;
     }
 
-    SLtt_Use_Ansi_Colors = 1;
+    MonoValue = getenv(MonoEnv);
+    if ( MonoValue == NULL ) {
+	SLtt_Use_Ansi_Colors = 1;
+    } else {
+	SLtt_Use_Ansi_Colors = 0;
+    }
 
     SLsmg_init_smg();
     SLang_init_tty(0, 0, 0);
@@ -141,25 +156,32 @@ int newtFinished(void) {
 }
 
 void newtSetColors(struct newtColors colors) {
-    SLtt_set_color(COLORSET_ROOT, "", colors.rootFg, colors.rootBg);
-    SLtt_set_color(COLORSET_BORDER, "", colors.borderFg, colors.borderBg);
-    SLtt_set_color(COLORSET_WINDOW, "", colors.windowFg, colors.windowBg);
-    SLtt_set_color(COLORSET_SHADOW, "", colors.shadowFg, colors.shadowBg);
-    SLtt_set_color(COLORSET_TITLE, "", colors.titleFg, colors.titleBg);
-    SLtt_set_color(COLORSET_BUTTON, "", colors.buttonFg, colors.buttonBg);
-    SLtt_set_color(COLORSET_ACTBUTTON, "", colors.actButtonFg, 
+    SLtt_set_color(NEWT_COLORSET_ROOT, "", colors.rootFg, colors.rootBg);
+    SLtt_set_color(NEWT_COLORSET_BORDER, "", colors.borderFg, colors.borderBg);
+    SLtt_set_color(NEWT_COLORSET_WINDOW, "", colors.windowFg, colors.windowBg);
+    SLtt_set_color(NEWT_COLORSET_SHADOW, "", colors.shadowFg, colors.shadowBg);
+    SLtt_set_color(NEWT_COLORSET_TITLE, "", colors.titleFg, colors.titleBg);
+    SLtt_set_color(NEWT_COLORSET_BUTTON, "", colors.buttonFg, colors.buttonBg);
+    SLtt_set_color(NEWT_COLORSET_ACTBUTTON, "", colors.actButtonFg, 
 			colors.actButtonBg);
-    SLtt_set_color(COLORSET_CHECKBOX, "", colors.checkboxFg, colors.checkboxBg);
-    SLtt_set_color(COLORSET_ACTCHECKBOX, "", colors.actCheckboxFg, 
+    SLtt_set_color(NEWT_COLORSET_CHECKBOX, "", colors.checkboxFg, 
+			colors.checkboxBg);
+    SLtt_set_color(NEWT_COLORSET_ACTCHECKBOX, "", colors.actCheckboxFg, 
 			colors.actCheckboxBg);
-    SLtt_set_color(COLORSET_ENTRY, "", colors.entryFg, colors.entryBg);
-    SLtt_set_color(COLORSET_LABEL, "", colors.labelFg, colors.labelBg);
-    SLtt_set_color(COLORSET_LISTBOX, "", colors.listboxFg, colors.listboxBg);
-    SLtt_set_color(COLORSET_ACTLISTBOX, "", colors.actListboxFg, 
-					    colors.actListboxBg);
-    SLtt_set_color(COLORSET_TEXTBOX, "", colors.textboxFg, colors.textboxBg);
-    SLtt_set_color(COLORSET_ACTTEXTBOX, "", colors.actTextboxFg, 
-					    colors.actTextboxBg);
+    SLtt_set_color(NEWT_COLORSET_ENTRY, "", colors.entryFg, colors.entryBg);
+    SLtt_set_color(NEWT_COLORSET_LABEL, "", colors.labelFg, colors.labelBg);
+    SLtt_set_color(NEWT_COLORSET_LISTBOX, "", colors.listboxFg, 
+			colors.listboxBg);
+    SLtt_set_color(NEWT_COLORSET_ACTLISTBOX, "", colors.actListboxFg, 
+			colors.actListboxBg);
+    SLtt_set_color(NEWT_COLORSET_TEXTBOX, "", colors.textboxFg, 
+			colors.textboxBg);
+    SLtt_set_color(NEWT_COLORSET_ACTTEXTBOX, "", colors.actTextboxFg, 
+			colors.actTextboxBg);
+    SLtt_set_color(NEWT_COLORSET_HELPLINE, "", colors.helpLineFg, 
+			colors.helpLineBg);
+    SLtt_set_color(NEWT_COLORSET_ROOTTEXT, "", colors.rootTextFg, 
+			colors.rootTextBg);
 }
 
 int newtGetKey(void) {
@@ -263,7 +285,7 @@ int newtOpenWindow(int left, int top, int width, int height,
 	}
     }
 
-    SLsmg_set_color(COLORSET_BORDER);
+    SLsmg_set_color(NEWT_COLORSET_BORDER);
     SLsmg_draw_box(top - 1, left - 1, height + 2, width + 2);
 
     if (title) {
@@ -274,19 +296,19 @@ int newtOpenWindow(int left, int top, int width, int height,
 	SLsmg_write_char(SLSMG_RTEE_CHAR);
 	SLsmg_set_char_set(0);
 	SLsmg_write_char(' ');
-	SLsmg_set_color(COLORSET_TITLE);
+	SLsmg_set_color(NEWT_COLORSET_TITLE);
 	SLsmg_write_string(title);
-	SLsmg_set_color(COLORSET_BORDER);
+	SLsmg_set_color(NEWT_COLORSET_BORDER);
 	SLsmg_write_char(' ');
 	SLsmg_set_char_set(1);
 	SLsmg_write_char(SLSMG_LTEE_CHAR);
 	SLsmg_set_char_set(0);
     }
 
-    SLsmg_set_color(COLORSET_WINDOW);
+    SLsmg_set_color(NEWT_COLORSET_WINDOW);
     SLsmg_fill_region(top, left, height, width, ' ');
 
-    SLsmg_set_color(COLORSET_SHADOW);
+    SLsmg_set_color(NEWT_COLORSET_SHADOW);
     SLsmg_fill_region(top + height + 1, left, 1, width + 2, ' ');
     SLsmg_fill_region(top, left + width + 1, height + 1, 1, ' ');
 
@@ -341,7 +363,7 @@ void newtDrawBox(int left, int top, int width, int height, int shadow) {
     SLsmg_draw_box(top, left, height, width);
 
     if (shadow) {
-	SLsmg_set_color(COLORSET_SHADOW);
+	SLsmg_set_color(NEWT_COLORSET_SHADOW);
 	SLsmg_fill_region(top + height, left + 1, 1, width - 1, ' ');
 	SLsmg_fill_region(top + 1, left + width, height, 1, ' ');
     }
@@ -396,3 +418,60 @@ struct eventResult newtDefaultEventHandler(struct newtComponent * c,
     er.result = ER_IGNORED;
     return er;
 }
+
+void newtRedrawHelpLine(void) {
+    char * buf;
+
+    SLsmg_set_color(NEWT_COLORSET_HELPLINE);
+   
+    buf = alloca(SLtt_Screen_Cols + 1);
+    memset(buf, ' ', SLtt_Screen_Cols);
+    buf[SLtt_Screen_Cols] = '\0';
+
+    if (currentHelpline)
+	memcpy(buf, *currentHelpline, strlen(*currentHelpline));
+
+    SLsmg_gotorc(SLtt_Screen_Rows - 1, 0);
+    SLsmg_write_string(buf);
+}
+
+void newtPushHelpLine(char * text) {
+    if (!text)
+	text = defaultHelpLine;
+    
+    if (currentHelpline)
+	(*(++currentHelpline)) = strdup(text);
+    else {
+	currentHelpline = helplineStack;
+	*currentHelpline = strdup(text);
+    }
+
+    newtRedrawHelpLine();
+}
+
+void newtPopHelpLine(void) {
+    if (!currentHelpline) return;
+
+    free(*currentHelpline);
+    if (currentHelpline == helplineStack)
+	currentHelpline = NULL;
+    else
+	currentHelpline--;
+
+    newtRedrawHelpLine();
+}
+
+void newtDrawRootText(int row, int col, char * text) {
+    SLsmg_set_color(NEWT_COLORSET_ROOTTEXT);
+
+    if (col < 0) {
+	col = SLtt_Screen_Cols + col;
+    }
+
+    if (row < 0) {
+	col = SLtt_Screen_Cols + col;
+    }
+   
+    SLsmg_gotorc(row, col);
+    SLsmg_write_string(text);
+}
